window.Gleam.initSearch([{"doc":"espresso","title":"espresso","content":"# espresso\n\n_This package is experimental and likely to change. Use at your own risk_\n\n[![Package Version](https://img.shields.io/hexpm/v/espresso)](https://hex.pm/packages/espresso)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/espresso/)\n\nA simple to use HTTP server built on top of erlang&#39;s cowboy.\n\n```gleam\nimport espresso\nimport espresso/request.{Request}\nimport espresso/response.{send}\nimport espresso/router.{get}\n\npub fn main() {\n  let router =\n    router.new()\n    |&gt; get(&quot;/&quot;, fn(_req: Request(BitString)) { send(202, &quot;Main Route&quot;) })\n\n  espresso.start(router)\n}\n```\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add espresso\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/espresso&gt;.\n","url":"index.html"},{"doc":"espresso/request","title":"Params","content":"pub type Params =\n  List(#(String, String))\n\n\nSynonyms:\nespresso/request.Params\nespresso/request Params","url":"espresso/request.html#Params"},{"doc":"espresso/request","title":"Request","content":"pub type Request(body, assigns) {\n  Request(\n    method: Method,\n    headers: List(Header),\n    body: body,\n    scheme: Scheme,\n    host: String,\n    port: Option(Int),\n    path: String,\n    query: Option(String),\n    params: Params,\n    assigns: Option(assigns),\n  )\n}\n Represents an HTTP request.\n Contains most of the pieces of a URI but additionally contains\n the HTTP method, headers, and body. Also contains the params which\n are the parsed elements of a router path.\nRequest(\n  method: Method,\n  headers: List(Header),\n  body: body,\n  scheme: Scheme,\n  host: String,\n  port: Option(Int),\n  path: String,\n  query: Option(String),\n  params: Params,\n  assigns: Option(assigns),\n)\n\n\nSynonyms:\nespresso/request.Request\nespresso/request Request","url":"espresso/request.html#Request"},{"doc":"espresso/request","title":"assign","content":"pub fn assign(req: Request(a, b), assigns: b) -&gt; Request(a, b)\n Set the assigns of the request, overwriting any existing assigns.\n\n # Examples\n \n \n type Assigns {\n  Assigns(authorized: Bool)\n }\n \n let router =\n    router.new()\n    |&gt; router.middleware(fn(next: Service(BitString, Assigns, BitBuilder)) {\n      fn(req: Request(BitString, Assigns)) {\n        let auth = request.get_header(req, &quot;authorization&quot;)\n        case auth {\n          Ok(&quot;Basic OnN1cGVyc2VjcmV0&quot;) -&gt;\n            req\n            |&gt; assign(Assigns(authorized: True))\n            |&gt; next()\n          _ -&gt; send(401, &quot;Unauthorized&quot;)\n       }\n      }\n    })\n    |&gt; get(\n      &quot;/&quot;,\n      fn(_req: Request(BitString, Assigns)) { \n          // req.assigns here will be Some(Assigns(authorized: True))\n          // if the basic auth password is &quot;supersecret&quot;\n          send(202, &quot;Main Route&quot;) \n      }    \n   )\n \nSynonyms:\nespresso/request.assign\nespresso/request assign","url":"espresso/request.html#assign"},{"doc":"espresso/request","title":"from_uri","content":"pub fn from_uri(uri: Uri) -&gt; Result(Request(String, a), Nil)\n Construct a request from a URI.\n\nSynonyms:\nespresso/request.from_uri\nespresso/request from_uri","url":"espresso/request.html#from_uri"},{"doc":"espresso/request","title":"get_cookies","content":"pub fn get_cookies(req: Request(a, b)) -&gt; List(#(String, String))\n Fetch the cookies sent in a request.\n\n Note badly formed cookie pairs will be ignored.\n RFC6265 specifies that invalid cookie names/attributes should be ignored.\nSynonyms:\nespresso/request.get_cookies\nespresso/request get_cookies","url":"espresso/request.html#get_cookies"},{"doc":"espresso/request","title":"get_header","content":"pub fn get_header(request: Request(a, b), key: String) -&gt; Result(\n  String,\n  Nil,\n)\n Get the value for a given header.\n\n If the request does not have that header then `Error(Nil)` is returned.\n\nSynonyms:\nespresso/request.get_header\nespresso/request get_header","url":"espresso/request.html#get_header"},{"doc":"espresso/request","title":"get_param","content":"pub fn get_param(req: Request(a, b), name: String) -&gt; Option(\n  String,\n)\n Utility function to get a router param from the request.\n \n # Examples\n \n import espresso/request.{Request}\n \n fn handler(req: Request(a)) {\n   let id = req |&gt; request.get_param(&quot;id&quot;) |&gt; option.unwrap(&quot;&quot;)\n }\n \nSynonyms:\nespresso/request.get_param\nespresso/request get_param","url":"espresso/request.html#get_param"},{"doc":"espresso/request","title":"get_query","content":"pub fn get_query(request: Request(a, b)) -&gt; Result(\n  List(#(String, String)),\n  Nil,\n)\n Decode the query of a request.\nSynonyms:\nespresso/request.get_query\nespresso/request get_query","url":"espresso/request.html#get_query"},{"doc":"espresso/request","title":"map","content":"pub fn map(request: Request(a, b), transform: fn(a) -&gt; c) -&gt; Request(\n  c,\n  b,\n)\n Update the body of a request using a given function.\n\nSynonyms:\nespresso/request.map\nespresso/request map","url":"espresso/request.html#map"},{"doc":"espresso/request","title":"new","content":"pub fn new() -&gt; Request(String, a)\n A request with commonly used default values. This request can be used as\n an initial value and then update to create the desired request.\n\nSynonyms:\nespresso/request.new\nespresso/request new","url":"espresso/request.html#new"},{"doc":"espresso/request","title":"path_segments","content":"pub fn path_segments(request: Request(a, b)) -&gt; List(String)\n Return the non-empty segments of a request path.\n\nSynonyms:\nespresso/request.path_segments\nespresso/request path_segments","url":"espresso/request.html#path_segments"},{"doc":"espresso/request","title":"prepend_header","content":"pub fn prepend_header(request: Request(a, b), key: String, value: String) -&gt; Request(\n  a,\n  b,\n)\n Prepend the header with the given value under the given header key.\n\n Similar to `set_header` except if the header already exists it prepends\n another header with the same key.\nSynonyms:\nespresso/request.prepend_header\nespresso/request prepend_header","url":"espresso/request.html#prepend_header"},{"doc":"espresso/request","title":"set_body","content":"pub fn set_body(req: Request(a, b), body: c) -&gt; Request(c, b)\n Set the body of the request, overwriting any existing body.\n\nSynonyms:\nespresso/request.set_body\nespresso/request set_body","url":"espresso/request.html#set_body"},{"doc":"espresso/request","title":"set_cookie","content":"pub fn set_cookie(req: Request(a, b), name: String, value: String) -&gt; Request(\n  a,\n  b,\n)\n Send a cookie with a request\n\n Multiple cookies are added to the same cookie header.\nSynonyms:\nespresso/request.set_cookie\nespresso/request set_cookie","url":"espresso/request.html#set_cookie"},{"doc":"espresso/request","title":"set_header","content":"pub fn set_header(request: Request(a, b), key: String, value: String) -&gt; Request(\n  a,\n  b,\n)\n Set the header with the given value under the given header key.\n\n If already present, it is replaced.\nSynonyms:\nespresso/request.set_header\nespresso/request set_header","url":"espresso/request.html#set_header"},{"doc":"espresso/request","title":"set_host","content":"pub fn set_host(req: Request(a, b), host: String) -&gt; Request(a, b)\n Set the method of the request.\n\nSynonyms:\nespresso/request.set_host\nespresso/request set_host","url":"espresso/request.html#set_host"},{"doc":"espresso/request","title":"set_method","content":"pub fn set_method(req: Request(a, b), method: Method) -&gt; Request(\n  a,\n  b,\n)\n Set the method of the request.\n\nSynonyms:\nespresso/request.set_method\nespresso/request set_method","url":"espresso/request.html#set_method"},{"doc":"espresso/request","title":"set_path","content":"pub fn set_path(req: Request(a, b), path: String) -&gt; Request(a, b)\n Set the path of the request.\n\nSynonyms:\nespresso/request.set_path\nespresso/request set_path","url":"espresso/request.html#set_path"},{"doc":"espresso/request","title":"set_port","content":"pub fn set_port(req: Request(a, b), port: Int) -&gt; Request(a, b)\n Set the port of the request.\n\nSynonyms:\nespresso/request.set_port\nespresso/request set_port","url":"espresso/request.html#set_port"},{"doc":"espresso/request","title":"set_query","content":"pub fn set_query(req: Request(a, b), query: List(\n    #(String, String),\n  )) -&gt; Request(a, b)\n Set the query of the request.\n\nSynonyms:\nespresso/request.set_query\nespresso/request set_query","url":"espresso/request.html#set_query"},{"doc":"espresso/request","title":"set_scheme","content":"pub fn set_scheme(req: Request(a, b), scheme: Scheme) -&gt; Request(\n  a,\n  b,\n)\n Set the scheme (protocol) of the request.\n\nSynonyms:\nespresso/request.set_scheme\nespresso/request set_scheme","url":"espresso/request.html#set_scheme"},{"doc":"espresso/request","title":"to","content":"pub fn to(url: String) -&gt; Result(Request(String, a), Nil)\n Construct a request from a URL string\n\nSynonyms:\nespresso/request.to\nespresso/request to","url":"espresso/request.html#to"},{"doc":"espresso/request","title":"to_uri","content":"pub fn to_uri(request: Request(a, b)) -&gt; Uri\n Return the uri that a request was sent to.\n\nSynonyms:\nespresso/request.to_uri\nespresso/request to_uri","url":"espresso/request.html#to_uri"},{"doc":"espresso/request","title":"espresso/request","content":"","url":"espresso/request.html"},{"doc":"espresso/query","title":"get","content":"pub fn get(req: Request(a, b), name: String) -&gt; Option(String)\n Get a query parameter from a request.\n \n # Examples\n \n \n import espresso/request.{Request}\n import espresso/query\n \n fn handler(req: Request(a)) {\n  let name = query.get(req, &quot;name&quot;)\n  case name {\n    Some(name) -&gt; ...\n    None -&gt; ...\n  }\n }\n \nSynonyms:\nespresso/query.get\nespresso/query get","url":"espresso/query.html#get"},{"doc":"espresso/query","title":"espresso/query","content":" Helper module for extracting query parameters from a request.\n ","url":"espresso/query.html"},{"doc":"espresso/response","title":"Response","content":"pub type Response(body) {\n  Response(status: Int, headers: List(Header), body: body)\n}\n Type that represents an HTTP response.\nResponse(status: Int, headers: List(Header), body: body)\n\n\nSynonyms:\nespresso/response.Response\nespresso/response Response","url":"espresso/response.html#Response"},{"doc":"espresso/response","title":"expire_cookie","content":"pub fn expire_cookie(response: Response(a), name: String, attributes: Attributes) -&gt; Response(\n  a,\n)\n Expire a cookie value for a client\n\n Note: The attributes value should be the same as when the response cookie was set.\nSynonyms:\nespresso/response.expire_cookie\nespresso/response expire_cookie","url":"espresso/response.html#expire_cookie"},{"doc":"espresso/response","title":"get_cookies","content":"pub fn get_cookies(resp: Response(a)) -&gt; List(#(String, String))\n Fetch the cookies sent in a response. \n\n Badly formed cookies will be discarded.\n\nSynonyms:\nespresso/response.get_cookies\nespresso/response get_cookies","url":"espresso/response.html#get_cookies"},{"doc":"espresso/response","title":"get_header","content":"pub fn get_header(response: Response(a), key: String) -&gt; Result(\n  String,\n  Nil,\n)\n Get the value for a given header.\n\n If the response does not have that header then `Error(Nil)` is returned.\n\nSynonyms:\nespresso/response.get_header\nespresso/response get_header","url":"espresso/response.html#get_header"},{"doc":"espresso/response","title":"json","content":"pub fn json(data: Json) -&gt; Response(BitBuilder)\n Given json data, sends a 200 response with the json data as the body.\n \n # Example\n \n \n import espresso/request.{Request}\n import espresso/response\n import cat\n \n fn handler(_req: Request) {\n   Cat(name: &quot;Test&quot;) \n   |&gt; cat.encode()\n   |&gt; response.json()\n }\n \n \nSynonyms:\nespresso/response.json\nespresso/response json","url":"espresso/response.html#json"},{"doc":"espresso/response","title":"json2","content":"pub fn json2(res: Response(a), data: Json) -&gt; Response(BitBuilder)\n Similar to `json` but allows you to override more fields in the response.\n \n # Example\n \n \n import espresso/request.{Request}\n import espresso/response\n import cat\n \n fn handler(_req: Request) {\n   let cat = Cat(name: &quot;Test&quot;) \n   \n   201\n   |&gt; response.new()\n   |&gt; response.json2(cat.encode(cat))\n }\n \n \nSynonyms:\nespresso/response.json2\nespresso/response json2","url":"espresso/response.html#json2"},{"doc":"espresso/response","title":"map","content":"pub fn map(response: Response(a), transform: fn(a) -&gt; b) -&gt; Response(\n  b,\n)\n Update the body of a response using a given function.\n\nSynonyms:\nespresso/response.map\nespresso/response map","url":"espresso/response.html#map"},{"doc":"espresso/response","title":"new","content":"pub fn new(status: Int) -&gt; Response(BitBuilder)\n Construct an empty Response.\n\n The body type of the returned response is `String` and could be set with a\n call to `set_body`.\n\nSynonyms:\nespresso/response.new\nespresso/response new","url":"espresso/response.html#new"},{"doc":"espresso/response","title":"prepend_header","content":"pub fn prepend_header(response: Response(a), key: String, value: String) -&gt; Response(\n  a,\n)\n Prepend the header with the given value under the given header key.\n\n Similar to `set_header` except if the header already exists it prepends\n another header with the same key.\nSynonyms:\nespresso/response.prepend_header\nespresso/response prepend_header","url":"espresso/response.html#prepend_header"},{"doc":"espresso/response","title":"redirect","content":"pub fn redirect(uri: String) -&gt; Response(BitBuilder)\n Create a response that redirects to the given uri.\n\nSynonyms:\nespresso/response.redirect\nespresso/response redirect","url":"espresso/response.html#redirect"},{"doc":"espresso/response","title":"send","content":"pub fn send(status: Int, body: String) -&gt; Response(BitBuilder)\n sends a generic response with the given status code and text body.\n \n # Example\n \n \n import espresso/request.{Request}\n \n fn handler(_req: Request) {\n  response.send(200, &quot;Hello World&quot;)\n }\n \nSynonyms:\nespresso/response.send\nespresso/response send","url":"espresso/response.html#send"},{"doc":"espresso/response","title":"set_body","content":"pub fn set_body(response: Response(a), body: b) -&gt; Response(b)\n Set the body of the response, overwriting any existing body.\n\nSynonyms:\nespresso/response.set_body\nespresso/response set_body","url":"espresso/response.html#set_body"},{"doc":"espresso/response","title":"set_cookie","content":"pub fn set_cookie(response: Response(a), name: String, value: String, attributes: Attributes) -&gt; Response(\n  a,\n)\n Set a cookie value for a client\n\nSynonyms:\nespresso/response.set_cookie\nespresso/response set_cookie","url":"espresso/response.html#set_cookie"},{"doc":"espresso/response","title":"set_header","content":"pub fn set_header(response: Response(a), key: String, value: String) -&gt; Response(\n  a,\n)\n Set the header with the given value under the given header key.\n\n If the response already has that key, it is replaced.\nSynonyms:\nespresso/response.set_header\nespresso/response set_header","url":"espresso/response.html#set_header"},{"doc":"espresso/response","title":"try_map","content":"pub fn try_map(response: Response(a), transform: fn(a) -&gt;\n    Result(b, c)) -&gt; Result(Response(b), c)\n Update the body of a response using a given result returning function.\n\n If the given function returns an `Ok` value the body is set, if it returns\n an `Error` value then the error is returned.\n\nSynonyms:\nespresso/response.try_map\nespresso/response try_map","url":"espresso/response.html#try_map"},{"doc":"espresso/response","title":"espresso/response","content":" Module for interacting and sending HTTP responses.\n \n Forked from: https://github.com/gleam-lang/http/blob/v3.2.0/src/gleam/http/response.gleam","url":"espresso/response.html"},{"doc":"espresso/service","title":"Middleware","content":"pub type Middleware(\n  before_req,\n  assigns,\n  before_resp,\n  after_req,\n  after_resp,\n) =\n  fn(Service(before_req, assigns, before_resp)) -&gt;\n    Service(after_req, assigns, after_resp)\n Middleware are functions that take a before req/res and return a \n new req/res. They are used to transform requests and responses.\n\nSynonyms:\nespresso/service.Middleware\nespresso/service Middleware","url":"espresso/service.html#Middleware"},{"doc":"espresso/service","title":"Service","content":"pub type Service(in, assigns, out) =\n  fn(Request(in, assigns)) -&gt; Response(out)\n Services are functions that take a request and return a response.\n They are the core building block of web applications.\n\nSynonyms:\nespresso/service.Service\nespresso/service Service","url":"espresso/service.html#Service"},{"doc":"espresso/service","title":"map_response_body","content":"pub fn map_response_body(service: fn(Request(a, b)) -&gt;\n    Response(c), with mapper: fn(c) -&gt; d) -&gt; fn(Request(a, b)) -&gt;\n  Response(d)\n A middleware that transforms the response body returned by the service using\n a given function.\n\nSynonyms:\nespresso/service.map_response_body\nespresso/service map_response_body","url":"espresso/service.html#map_response_body"},{"doc":"espresso/service","title":"method_override","content":"pub fn method_override(service: fn(Request(a, b)) -&gt; Response(c)) -&gt; fn(\n  Request(a, b),\n) -&gt; Response(c)\n A middleware that overrides an incoming POST request with a method given in\n the request&#39;s `_method` query paramerter. This is useful as web browsers\n typically only support GET and POST requests, but our application may\n expect other HTTP methods that are more semantically correct.\n\n The methods PUT, PATCH, and DELETE are accepted for overriding, all others\n are ignored.\n\n The `_method` query paramerter can be specified in a HTML form like so:\n\n    &lt;form method=&quot;POST&quot; action=&quot;/item/1?_method=DELETE&quot;&gt;\n      &lt;button type=&quot;submit&quot;&gt;Delete item&lt;/button&gt;\n    &lt;/form&gt;\n\nSynonyms:\nespresso/service.method_override\nespresso/service method_override","url":"espresso/service.html#method_override"},{"doc":"espresso/service","title":"prepend_response_header","content":"pub fn prepend_response_header(service: fn(Request(a, b)) -&gt;\n    Response(c), key: String, value: String) -&gt; fn(Request(a, b)) -&gt;\n  Response(c)\n A middleware that prepends a header to the request.\n\nSynonyms:\nespresso/service.prepend_response_header\nespresso/service prepend_response_header","url":"espresso/service.html#prepend_response_header"},{"doc":"espresso/service","title":"espresso/service","content":" Service module that&#39;s mostly the same as the one in gleam/http but\n instead of taking gleam/http request and response it takes espresso versions.\n \n Forked from https://github.com/gleam-lang/http/blob/v3.2.0/src/gleam/http/service.gleam","url":"espresso/service.html"},{"doc":"espresso/ordered_map","title":"OrderedMap","content":"pub type OrderedMap(a, b) =\n  List(#(a, b))\n\n\nSynonyms:\nespresso/ordered_map.OrderedMap\nespresso/ordered_map OrderedMap","url":"espresso/ordered_map.html#OrderedMap"},{"doc":"espresso/ordered_map","title":"fold","content":"pub fn fold(map: List(#(a, b)), initial: c, fun: fn(c, a, b) -&gt; c) -&gt; c\n\nSynonyms:\nespresso/ordered_map.fold\nespresso/ordered_map fold","url":"espresso/ordered_map.html#fold"},{"doc":"espresso/ordered_map","title":"get","content":"pub fn get(map: List(#(a, b)), key: a) -&gt; Option(b)\n\nSynonyms:\nespresso/ordered_map.get\nespresso/ordered_map get","url":"espresso/ordered_map.html#get"},{"doc":"espresso/ordered_map","title":"insert","content":"pub fn insert(map: List(#(a, b)), key: a, value: b) -&gt; List(\n  #(a, b),\n)\n\nSynonyms:\nespresso/ordered_map.insert\nespresso/ordered_map insert","url":"espresso/ordered_map.html#insert"},{"doc":"espresso/ordered_map","title":"new","content":"pub fn new() -&gt; List(#(a, b))\n\nSynonyms:\nespresso/ordered_map.new\nespresso/ordered_map new","url":"espresso/ordered_map.html#new"},{"doc":"espresso/ordered_map","title":"update","content":"pub fn update(map: List(#(a, b)), key: a, fun: fn(Option(b)) -&gt; b) -&gt; List(\n  #(a, b),\n)\n\nSynonyms:\nespresso/ordered_map.update\nespresso/ordered_map update","url":"espresso/ordered_map.html#update"},{"doc":"espresso/ordered_map","title":"espresso/ordered_map","content":" Utility module for dealing with &quot;OrderedMaps&quot; which are lists\n of key/value pairs that are ordered by the key. It should have\n a similar interface to Map so you can swap them in and out,\n though not all the functions are implemented.\n \n Since it is based on lists it will not be as efficient as maps but\n for our use case we only care about the ordering.","url":"espresso/ordered_map.html"},{"doc":"espresso/static","title":"Static","content":"pub type Static {\n  File(String)\n  Dir(String)\n}\n The type of static file to serve. Either dir for directory\n or file for a single file.\n \n # Examples\n \n \n File(&quot;priv/index.html&quot;)\n Dir(&quot;priv&quot;)\n \n \n https://ninenines.eu/docs/en/cowboy/2.10/manual/cowboy_static/\nFile(String)\n\n\nDir(String)\n\n\nSynonyms:\nespresso/static.Static\nespresso/static Static","url":"espresso/static.html#Static"},{"doc":"espresso/static","title":"espresso/static","content":"","url":"espresso/static.html"},{"doc":"cowboy/cowboy","title":"CowboyRequest","content":"pub external type CowboyRequest\n An incoming request that will be handled by the dispatch in gleam_cowboy_native.erl\n\nSynonyms:\ncowboy/cowboy.CowboyRequest\ncowboy/cowboy CowboyRequest","url":"cowboy/cowboy.html#CowboyRequest"},{"doc":"cowboy/cowboy","title":"CowboyRouter","content":"pub external type CowboyRouter\n The returned result of cowboy_router:compile\n\nSynonyms:\ncowboy/cowboy.CowboyRouter\ncowboy/cowboy CowboyRouter","url":"cowboy/cowboy.html#CowboyRouter"},{"doc":"cowboy/cowboy","title":"Route","content":"pub type Route(req, assigns, res) {\n  ServiceRoute(Service(req, assigns, res))\n  RouterRoute(Routes(req, assigns, res))\n  StaticRoute(String, Static)\n}\n A Route can either be a service (a function that handles a request and response)\n or a router which is expanded into a list of services.\nServiceRoute(Service(req, assigns, res))\n\n\nRouterRoute(Routes(req, assigns, res))\n\n\nStaticRoute(String, Static)\n\n\nSynonyms:\ncowboy/cowboy.Route\ncowboy/cowboy Route","url":"cowboy/cowboy.html#Route"},{"doc":"cowboy/cowboy","title":"Routes","content":"pub type Routes(req, assigns, res) =\n  OrderedMap(String, Route(req, assigns, res))\n Routes are the mapping between a path and the route. \n For example `/hello` -&gt; `hello_service`\n\nSynonyms:\ncowboy/cowboy.Routes\ncowboy/cowboy Routes","url":"cowboy/cowboy.html#Routes"},{"doc":"cowboy/cowboy","title":"router","content":"pub fn router(routes: List(#(String, Route(a, b, c)))) -&gt; CowboyRouter\n Takes a list of route structures and compiles them into a cowboy router.\n \nSynonyms:\ncowboy/cowboy.router\ncowboy/cowboy router","url":"cowboy/cowboy.html#router"},{"doc":"cowboy/cowboy","title":"start","content":"pub fn start(router: CowboyRouter, on_port number: Int) -&gt; Result(\n  Pid,\n  Dynamic,\n)\n Start the cowboy server on the given port.\n \nSynonyms:\ncowboy/cowboy.start\ncowboy/cowboy start","url":"cowboy/cowboy.html#start"},{"doc":"cowboy/cowboy","title":"cowboy/cowboy","content":" This is a simple wrapper over the erlang cowboy server. It is originall from gleam-lang/cowboy\n but has been modified to work with espresso.\n \n original source:\n https://github.com/gleam-lang/cowboy/blob/83e2f20170e4a73e5499238149313f8329a2f41a/src/gleam/http/cowboy.gleam","url":"cowboy/cowboy.html"},{"doc":"espresso/router","title":"Handler","content":"pub type Handler(req, assigns, res) {\n  ServiceHandler(OrderedMap(Method, Service(req, assigns, res)))\n  RouterHandler(Router(req, assigns, res))\n  StaticHandler(String, Static)\n}\n\nServiceHandler(OrderedMap(Method, Service(req, assigns, res)))\n\n\nRouterHandler(Router(req, assigns, res))\n\n\nStaticHandler(String, Static)\n\n\nSynonyms:\nespresso/router.Handler\nespresso/router Handler","url":"espresso/router.html#Handler"},{"doc":"espresso/router","title":"Method","content":"pub type Method {\n  ALL\n  GET\n  POST\n  PATCH\n  PUT\n  DELETE\n  HEAD\n  OPTIONS\n}\n\nALL\n\n\nGET\n\n\nPOST\n\n\nPATCH\n\n\nPUT\n\n\nDELETE\n\n\nHEAD\n\n\nOPTIONS\n\n\nSynonyms:\nespresso/router.Method\nespresso/router Method","url":"espresso/router.html#Method"},{"doc":"espresso/router","title":"Router","content":"pub type Router(req, assigns, res) {\n  Router(\n    middleware: Middleware(req, assigns, res, req, res),\n    handlers: OrderedMap(String, Handler(req, assigns, res)),\n    not_found: Service(req, assigns, res),\n  )\n}\n\nRouter(\n  middleware: Middleware(req, assigns, res, req, res),\n  handlers: OrderedMap(String, Handler(req, assigns, res)),\n  not_found: Service(req, assigns, res),\n)\n\n\nSynonyms:\nespresso/router.Router\nespresso/router Router","url":"espresso/router.html#Router"},{"doc":"espresso/router","title":"delete","content":"pub fn delete(router: Router(a, b, c), path: String, handler: fn(\n    Request(a, b),\n  ) -&gt; Response(c)) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.delete\nespresso/router delete","url":"espresso/router.html#delete"},{"doc":"espresso/router","title":"expand","content":"pub fn expand(path: String, handlers: List(\n    #(String, Handler(a, b, c)),\n  ), router: Router(a, b, c)) -&gt; List(#(String, Handler(a, b, c)))\n\nSynonyms:\nespresso/router.expand\nespresso/router expand","url":"espresso/router.html#expand"},{"doc":"espresso/router","title":"get","content":"pub fn get(router: Router(a, b, c), path: String, handler: fn(\n    Request(a, b),\n  ) -&gt; Response(c)) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.get\nespresso/router get","url":"espresso/router.html#get"},{"doc":"espresso/router","title":"handle","content":"pub fn handle(router: Router(a, b, c), routes: List(\n    #(Method, fn(Request(a, b)) -&gt; Response(c)),\n  )) -&gt; fn(Request(a, b)) -&gt; Response(c)\n\nSynonyms:\nespresso/router.handle\nespresso/router handle","url":"espresso/router.html#handle"},{"doc":"espresso/router","title":"middleware","content":"pub fn middleware(router: Router(a, b, c), middleware: fn(\n    fn(Request(a, b)) -&gt; Response(c),\n  ) -&gt; fn(Request(a, b)) -&gt; Response(c)) -&gt; Router(a, b, c)\n Sets the middleware for a router. This is a function that wraps all the router handlers under it.\n Currently it doesn&#39;t support more than one but that may work in the future.\n \n # Examples\n \n \n import espresso/router.{get, delete}\n import espresso/request.{Request}\n import espresso/service.{Service}\n \n router.new()\n |&gt; router.router(\n  &quot;/api&quot;,\n  router.new()\n  |&gt; router.middleware(fn(next: Service(BitString, BitBuilder)) {\n    fn(req: Request(BitString)) {\n      let auth = request.get_header(req, &quot;authorization&quot;)\n      case auth {\n        Ok(&quot;Basic OnN1cGVyc2VjcmV0&quot;) -&gt; next(req)\n        _ -&gt; send(401, &quot;Unauthorized&quot;)\n      }\n    }\n  })\n  |&gt; get(&quot;/things&quot;, fn(_req: Request(BitString)) { send(200, &quot;Things&quot;) })\n  |&gt; delete(&quot;/things&quot;, fn(_req: Request(BitString)) { send(204, &quot;&quot;) }),\n )\n \n \n \nSynonyms:\nespresso/router.middleware\nespresso/router middleware","url":"espresso/router.html#middleware"},{"doc":"espresso/router","title":"new","content":"pub fn new() -&gt; Router(a, b, BitBuilder)\n Instantiates a new router. This is usually the starting point for route\n definitions unless you want to override the types of the req, res, middleware or\n not_found handler.\n \n # Examples\n \n \n import espresso/router\n \n router.new()\n |&gt; get(&quot;/&quot;, fn(_req: Request(BitString)) { send(200, &quot;Success&quot;) })\n \nSynonyms:\nespresso/router.new\nespresso/router new","url":"espresso/router.html#new"},{"doc":"espresso/router","title":"patch","content":"pub fn patch(router: Router(a, b, c), path: String, handler: fn(\n    Request(a, b),\n  ) -&gt; Response(c)) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.patch\nespresso/router patch","url":"espresso/router.html#patch"},{"doc":"espresso/router","title":"post","content":"pub fn post(router: Router(a, b, c), path: String, handler: fn(\n    Request(a, b),\n  ) -&gt; Response(c)) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.post\nespresso/router post","url":"espresso/router.html#post"},{"doc":"espresso/router","title":"put","content":"pub fn put(router: Router(a, b, c), path: String, handler: fn(\n    Request(a, b),\n  ) -&gt; Response(c)) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.put\nespresso/router put","url":"espresso/router.html#put"},{"doc":"espresso/router","title":"router","content":"pub fn router(router: Router(a, b, c), path: String, subrouter: Router(\n    a,\n    b,\n    c,\n  )) -&gt; Router(a, b, c)\n\nSynonyms:\nespresso/router.router\nespresso/router router","url":"espresso/router.html#router"},{"doc":"espresso/router","title":"static","content":"pub fn static(router: Router(a, b, c), path: String, config: Static) -&gt; Router(\n  a,\n  b,\n  c,\n)\n Handles a request for a given path and returns static files\n Currently only supports File and Directory\n \n # Examples\n \n \n import espresso/router\n import espreso/static\n\n // Serves all files in the priv/public directory for any request starting with /public\n router.new()\n |&gt; router.static(&quot;/public/[...]&quot;, static.Dir(&quot;priv/public&quot;))\n \n // Serves only the index.html file from the priv/public directory\n router.new()\n |&gt; router.static(&quot;/&quot;, static.File(&quot;priv/public/index.html&quot;))\n \n \nSynonyms:\nespresso/router.static\nespresso/router static","url":"espresso/router.html#static"},{"doc":"espresso/router","title":"to_routes","content":"pub fn to_routes(router: Router(a, b, c)) -&gt; List(\n  #(String, Route(a, b, c)),\n)\n\nSynonyms:\nespresso/router.to_routes\nespresso/router to_routes","url":"espresso/router.html#to_routes"},{"doc":"espresso/router","title":"espresso/router","content":"","url":"espresso/router.html"},{"doc":"espresso","title":"get_port","content":"pub fn get_port() -&gt; Int\n Returns the port to listen on by reading the\n &quot;PORT&quot; environtment variable. \n \n Defaults to 3000.\n \nSynonyms:\nespresso.get_port\nespresso get_port","url":"espresso.html#get_port"},{"doc":"espresso","title":"start","content":"pub fn start(r: Router(a, b, c)) -&gt; Nil\n Starts the server with a router and returns the pid of the process.\n \n ## Example \n \n \n import espresso\n import espresso/request.{Request}\n import espresso/response.{send}\n import espresso/router.{get}\n\n pub fn main() {\n   let router =\n     router.new()\n     |&gt; get(&quot;/&quot;, fn(_req: Request(BitString)) { send(202, &quot;Main Route&quot;) })\n\n   espresso.start(router)\n }\n \n \nSynonyms:\nespresso.start\nespresso start","url":"espresso.html#start"},{"doc":"espresso","title":"espresso","content":" This is the base module for starting the http server. It also does things\n like retrieve the system port and halts but the main thing is the start\n function.","url":"espresso.html"}]);